# oranchada
[Orange](https://orangedatamining.com/) workflow add-on for processing [Raman spectra](https://en.wikipedia.org/wiki/Raman_spectroscopy). Based on [ramanchada2](https://github.com/h2020charisma/ramanchada2).


## Installation

1. If you don't already use Orange, get it for your operating system of choice from https://orangedatamining.com/download.

1. Once it's installed and running, open **Options** ➡️ **Add-ons**.

    ![screenshot](https://user-images.githubusercontent.com/1084155/220552655-48836b26-67bb-428e-822c-7ca606dbff03.png)

1. Click the **Add more...** button.

    ![screenshot](https://user-images.githubusercontent.com/1084155/220552771-187ee7d1-dcf9-4bbd-a679-3ff55ae60c4a.png)

1. Type `oranchada` in the **Name** field, then click **Add**.

    ![screenshot](https://user-images.githubusercontent.com/1084155/220552825-ab5f5b48-f262-44d6-953d-c57516649164.png)

1. Scroll down the list until you find **oranchada**, then click the box next to it so that a check mark appears and *Install* is displayed in the **Action** column. Then click **OK**.

    ![screenshot](https://user-images.githubusercontent.com/1084155/220552873-0920478b-6fb8-4ed7-be36-4594ade2fc07.png)

1. Orange will then proceed with the installation. When ready, it will suggest to restart itself. Click **OK**.

    ![screenshot](https://user-images.githubusercontent.com/1084155/220552907-f0a48b94-422d-497c-a1e1-fd1809f54f5e.png)

1. Once Orange restarts, you should see a **charisma** category in the left panel. Click it to reveal all widgets.

    ![screenshot](https://user-images.githubusercontent.com/1084155/220552964-d1c359ce-98e3-44f4-a8b6-15e500f75361.png)


## Updating

1. Open **Options** ➡️ **Add-ons**. If there's a new version of **oranchada**, it will be listed at the top, with your installed version and the latest available one indicated (e.g. you have `0.0.2` installed and `0.0.3` is the latest available version that you can update to).

    ![screenshot](https://user-images.githubusercontent.com/1084155/220553001-ec121e59-005c-447c-955e-d8f3b22ffdab.png)

1. Click the box next to it so that a check mark appears and *Update* is displayed in the **Action** column, then click **OK**.

    ![screenshot](https://user-images.githubusercontent.com/1084155/220553024-76e9861a-8b9c-410a-9c73-d98639b293a1.png)


## For developers

If you would like to install from cloned git repository, run

    pip install .

To register this add-on with Orange, but keep the code in the development
directory (do not copy it to Python's site-packages directory), run

    pip install -e .


## Acknowledgements

🇪🇺 This project has received funding from the European Union’s Horizon 2020 research and innovation program under [grant agreement No. 952921](https://cordis.europa.eu/project/id/952921).
